summaryrefslogtreecommitdiff
path: root/volk/python/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'volk/python/__init__.py')
-rw-r--r--volk/python/__init__.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/volk/python/__init__.py b/volk/python/__init__.py
index 6513a31dd..7239e7e23 100644
--- a/volk/python/__init__.py
+++ b/volk/python/__init__.py
@@ -1,5 +1,5 @@
#
-# Copyright 2008 Free Software Foundation, Inc.
+# Copyright 2010 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
@@ -38,12 +38,12 @@ if _RTLD_GLOBAL != 0:
# ----------------------------------------------------------------
-# import swig generated symbols into the libvector namespace
-from libvector_swig import *
+# import swig generated symbols into the volk namespace
+from volk_swig import *
# import any pure python here
# from libvector_foo import bar
# from libvector_baz import *
# ----------------------------------------------------------------
@@ -38,12 +38,12 @@ if _RTLD_GLOBAL != 0:
# import any pure python here
-# from libvector_foo import bar
-# from libvector_baz import *
+# from volk_foo import bar
+# from volk_baz import *
# ----------------------------------------------------------------